@@ -18,7 +18,7 @@ def set_env_variables():
         env_variable_path = f'{local_secret_file_folder_path}/env.json'
     elif os.name == 'posix':
         env_variable_path = '/env/env'
-    
+
     with open(env_variable_path, "r") as file:
         dict = json.load(file)
         for key, value in dict.items():
@@ -73,9 +73,10 @@ def generate_google_service_auth(service):
         google_service_auth = gspread.authorize(credentials)
 
     elif service == "googleads":
-        google_ads_client = GoogleAdsClient.load_from_storage(google_ads_secret())
+        google_ads_client = GoogleAdsClient.load_from_storage(
+            google_ads_secret())
         google_service_auth = google_ads_client.get_service(
-            "GoogleAdsService", version="v10")
+            "GoogleAdsService", version="v11")
     else:
         print("サービス未選択")
         return False
@@ -322,14 +323,12 @@ def download_rerort(token, account_id, report_job_id, fields):
         concat_dict_array = []
         for j in range(1, len(rows) - 2):
             row = rows[j].split(',')
-            if int(row[4]) > 0:
-                array = {}
-                array['SOURCE'] = 'Yahoo'
-                for i, value in enumerate(row):
-                    key = fields[i]
-                    array[f'{key}'] = value
+            array = {}
+            for i, value in enumerate(row):
+                key = fields[i]
+                array[f'{key}'] = value
 
-                concat_dict_array.append(array)
+            concat_dict_array.append(array)
 
         if concat_dict_array:
             return concat_dict_array
